@@ -16,7 +16,9 @@ QString ImportExport::getSavePath(void)
         return ImportExport::savePath;
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+    QString prefix = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
+#elif QT_VERSION >= QT_VERSION_CHECK(5,0,0)
     QString prefix = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
 #else
     QString prefix = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
@@ -112,7 +114,7 @@ void ImportExport::importProject(Speaker &speaker, SealedBox &sbox, PortedBox &p
         box = box.nextSiblingElement("box");
     }
 
-    if (number != NULL) {
+    if (number != nullptr) {
         QDomElement layout = root.firstChildElement("layout");
         if (layout.isNull())
             *number = 1; /* default */
@@ -120,7 +122,7 @@ void ImportExport::importProject(Speaker &speaker, SealedBox &sbox, PortedBox &p
             *number = layout.attribute("sibling", "1").toInt();
     }
 
-    if (tab != NULL) {
+    if (tab != nullptr) {
         QDomElement state = root.firstChildElement("state");
         if (state.isNull())
             *tab = 0;
