@@ -27,6 +27,29 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+    QUndoStack* getCommandStack() {
+        return this->commandStack;
+    };
+
+    void changeSpeakerNumber(int number);
+    void changeVendor(const QString &vendor, const Speaker& oldspeaker);
+    void changeModel(const QString &model);
+    void changeSealedVolume(double val);
+    void changePortedVolume(double val);
+    void changePortedResFreq(double val);
+    void changePortedPortNumber(unsigned int val);
+    void changePortedPortDiam(double val);
+    void changePortedSlotPortActivation(bool checked);
+    void changePortedSlotWidth(double val);
+    void changeBPSealedVolume(double val);
+    void changeBPPortedVolume(double val);
+    void changeBPPortedResFreq(double val);
+    void changeBPPortedPortNumber(double val);
+    void changeBPPortedPortDiam(double val);
+    void exportPlot(const QString& outfileName, int tabindex);
+    void exportScad3D(const QString& outfileName, int tabindex);
+    void exportScad2D(const QString& outfileName, int tabindex);
+    void exportScad(const QString &scad, const QString& outfileName, int tabindex);
 signals:
     void currentSpeakerChanged(Speaker spk);
     void currentSealedBoxChanged(SealedBox box);
@@ -46,6 +69,8 @@ public slots:
     void onEditOptimize();
     void onSpeakerSearch();
     void onProjectPrint();
+    void onUndo();
+    void onRedo();
     void onAboutAbout();
 
     void onSearchRequested(const QString& param, double min, double max);
@@ -72,6 +97,7 @@ public slots:
     void onPortedPortsNumberSpinChanged(int val);
     void onPortedPortDiameterDoubleSpinChanged(double val);
     void onPortedSlotWidthDoubleSpinChanged(double val);
+    void onPortedSlotPortActivated(bool checked);
 
     void onBandPassSealedVolumeDoubleSpinChanged(double val);
     void onBandPassPortedVolumeDoubleSpinChanged(double val);
@@ -89,6 +115,10 @@ public slots:
     void onBandpassOptimizeRequested(double s, double pa);
     void onBandpassOptimizeCancelled();
 
+    void onCurvePlot();
+    void on3DScadExport();
+    void on2DScadExport();
+
 protected:
     void linkMenus();
     void linkTabs();
@@ -116,8 +146,10 @@ private:
     ListDialog *listDialog;
     BandpassDialog *bandpassDialog;
 
+    Speaker oldSpeaker;
     Speaker currentSpeaker;
     int currentSpeakerNumber;
+
     SealedBox currentSealedBox;
     PortedBox currentPortedBox;
     BandPassBox currentBandPassBox;
@@ -129,6 +161,7 @@ private:
     Plot *bandpassPlot;
 
     const Speaker *notInDbSpeaker;
+    QUndoStack *commandStack;
 };
 
 #endif // MAINWINDOW_H
